@@ -77,6 +77,8 @@ from ncbi.datasets.openapi.model.v1_download_summary_file_summary import V1Downl
 from ncbi.datasets.openapi.model.v1_download_summary_file_summary import V1DownloadSummaryFileSummary as V1alpha1DownloadSummaryFileSummary
 from ncbi.datasets.openapi.model.v1_download_summary_hydrated import V1DownloadSummaryHydrated
 from ncbi.datasets.openapi.model.v1_download_summary_hydrated import V1DownloadSummaryHydrated as V1alpha1DownloadSummaryHydrated
+from ncbi.datasets.openapi.model.v1_element_flank_config import V1ElementFlankConfig
+from ncbi.datasets.openapi.model.v1_element_flank_config import V1ElementFlankConfig as V1alpha1ElementFlankConfig
 from ncbi.datasets.openapi.model.v1_error import V1Error
 from ncbi.datasets.openapi.model.v1_error import V1Error as V1alpha1Error
 from ncbi.datasets.openapi.model.v1_error_assembly_error_code import V1ErrorAssemblyErrorCode
@@ -127,8 +129,6 @@ from ncbi.datasets.openapi.model.v1_method_payload_request import V1MethodPayloa
 from ncbi.datasets.openapi.model.v1_method_payload_request import V1MethodPayloadRequest as V1alpha1MethodPayloadRequest
 from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request import V1MicroBiggeDatasetRequest
 from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request import V1MicroBiggeDatasetRequest as V1alpha1MicroBiggeDatasetRequest
-from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request_element_flank_config import V1MicroBiggeDatasetRequestElementFlankConfig
-from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request_element_flank_config import V1MicroBiggeDatasetRequestElementFlankConfig as V1alpha1MicroBiggeDatasetRequestElementFlankConfig
 from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request_file_type import V1MicroBiggeDatasetRequestFileType
 from ncbi.datasets.openapi.model.v1_micro_bigge_dataset_request_file_type import V1MicroBiggeDatasetRequestFileType as V1alpha1MicroBiggeDatasetRequestFileType
 from ncbi.datasets.openapi.model.v1_nomenclature_authority import V1NomenclatureAuthority
@@ -233,6 +233,8 @@ from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGe
 from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGeneWarningCode as V1alpha1WarningGeneWarningCode
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId as V1alpha1WarningReplacedId
+from ncbi.datasets.openapi.model.v1reports_assembly_status import V1reportsAssemblyStatus
+from ncbi.datasets.openapi.model.v1reports_assembly_status import V1reportsAssemblyStatus as V1alpha1reportsAssemblyStatus
 from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject
 from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject as V1alpha1reportsBioProject
 from ncbi.datasets.openapi.model.v1reports_bio_sample_attribute import V1reportsBioSampleAttribute
